Enum getopts::NameUnstable
[-] [+]
[src]
pub enum Name {
Long(String),
Short(char),
}Name of an option. Either a string or a single char.
Variants
Long | A string representing the long name of an option. For example: "help" |
Short | A char representing the short name of an option. For example: 'h' |