Function getopts::optoptUnstable
[-] [+]
[src]
pub fn optopt(short_name: &str, long_name: &str, desc: &str, hint: &str) -> OptGroup
Create a long option that is optional and takes an argument.
short_name- e.g."h"for a-hoption, or""for nonelong_name- e.g."help"for a--helpoption, or""for nonedesc- Description for usage helphint- Hint that is used in place of the argument in the usage help, e.g."FILE"for a-o FILEoption