Function getopts::short_usageUnstable
[-] [+]
[src]
pub fn short_usage(program_name: &str, opts: &[OptGroup]) -> String
Derive a short one-line usage summary from a set of long options.
pub fn short_usage(program_name: &str, opts: &[OptGroup]) -> String
Derive a short one-line usage summary from a set of long options.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).