Function getopts::usageUnstable
[-] [+]
[src]
pub fn usage(brief: &str, opts: &[OptGroup]) -> String
Derive a usage message from a set of long options.
pub fn usage(brief: &str, opts: &[OptGroup]) -> String
Derive a usage message from a set of long options.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).